<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nb">
<context>
    <name>QApplication</name>
    <message>
        <location filename="../main.cpp" line="53"/>
        <source>Unable to get exclusive lock</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="54"/>
        <source>Another package management application (like Synaptic or apt-get), is already running. Please close that application first</source>
        <translation>En annen pakkeinstallasjons applikasjon (som Synaptic eller apt-get) kjører allerede. Vennligst steng den applikasjonen først.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="67"/>
        <source>You must run this program as root.</source>
        <translation>Du må kjøre dette programmet som root.</translation>
    </message>
</context>
<context>
    <name>mxcodecs</name>
    <message>
        <location filename="../mxcodecs.ui" line="14"/>
        <source>MX Codecs Installer</source>
        <translation>MX Codec-installatør</translation>
    </message>
    <message>
        <location filename="../mxcodecs.ui" line="27"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p align=&quot;justify&quot;&gt;This application allows you to install restricted codecs that permit advanced video and audio functions.&lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;In some juridictions their distribution may be limited so the user must meet local regulations. &lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;&lt;br/&gt;&lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Do you assume legal responsibility for downloading these codecs?&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p align=&quot;justify&quot;&gt;Dette programmet lar deg installere avgrensede codecer som tillater avanserte video- og audiofunksjoner.&lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;I noen jurisdiksjoner kan distribusjonen være begrenset, brukeren må møte lokale lover og regler.&lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;&lt;br/&gt;&lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Tar du juridisk anvar for nedlasting av disse codecene?&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mxcodecs.ui" line="44"/>
        <source>Downloading codecs files</source>
        <translation>Laster ned codec filer</translation>
    </message>
    <message>
        <location filename="../mxcodecs.ui" line="94"/>
        <source>Cancel any changes then quit</source>
        <translation>Forkast alle endringer og avslutt</translation>
    </message>
    <message>
        <location filename="../mxcodecs.ui" line="97"/>
        <location filename="../mxcodecs.cpp" line="263"/>
        <source>Cancel</source>
        <translation>Avbryt</translation>
    </message>
    <message>
        <location filename="../mxcodecs.ui" line="105"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mxcodecs.ui" line="118"/>
        <source>Apply any changes then quit</source>
        <translation>Lagre alle endringer og avslutt</translation>
    </message>
    <message>
        <location filename="../mxcodecs.ui" line="121"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../mxcodecs.ui" line="177"/>
        <source>About this application</source>
        <translation>Om applikasjonen</translation>
    </message>
    <message>
        <location filename="../mxcodecs.ui" line="180"/>
        <source>About...</source>
        <translation>Om...</translation>
    </message>
    <message>
        <location filename="../mxcodecs.ui" line="188"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mxcodecs.ui" line="217"/>
        <source>Display help </source>
        <translation>Vis hjelp</translation>
    </message>
    <message>
        <location filename="../mxcodecs.ui" line="220"/>
        <source>Help</source>
        <translation>Hjelp</translation>
    </message>
    <message>
        <location filename="../mxcodecs.ui" line="228"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="113"/>
        <location filename="../mxcodecs.cpp" line="120"/>
        <location filename="../mxcodecs.cpp" line="128"/>
        <location filename="../mxcodecs.cpp" line="135"/>
        <location filename="../mxcodecs.cpp" line="143"/>
        <location filename="../mxcodecs.cpp" line="150"/>
        <location filename="../mxcodecs.cpp" line="159"/>
        <location filename="../mxcodecs.cpp" line="166"/>
        <source>&lt;b&gt;Running command...&lt;/b&gt;&lt;p&gt;</source>
        <translation>&lt;b&gt;Utfører kommando&lt;/b&gt;&lt;p&gt;</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="116"/>
        <location filename="../mxcodecs.cpp" line="131"/>
        <location filename="../mxcodecs.cpp" line="137"/>
        <location filename="../mxcodecs.cpp" line="146"/>
        <location filename="../mxcodecs.cpp" line="152"/>
        <location filename="../mxcodecs.cpp" line="162"/>
        <location filename="../mxcodecs.cpp" line="168"/>
        <location filename="../mxcodecs.cpp" line="197"/>
        <location filename="../mxcodecs.cpp" line="240"/>
        <source>Error</source>
        <translation>Feil</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="117"/>
        <location filename="../mxcodecs.cpp" line="132"/>
        <location filename="../mxcodecs.cpp" line="147"/>
        <location filename="../mxcodecs.cpp" line="163"/>
        <source>Cannot connect to the download site</source>
        <translation>Kan ikke koble til nedlastingssiden</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="123"/>
        <location filename="../mxcodecs.cpp" line="138"/>
        <location filename="../mxcodecs.cpp" line="153"/>
        <location filename="../mxcodecs.cpp" line="169"/>
        <source>Error downloading %1</source>
        <translation>Feil ved nedlasting av %1</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="174"/>
        <source>&lt;b&gt;Download Finished.&lt;/b&gt;</source>
        <translation>&lt;b&gt;Nedlasting fullført.&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="193"/>
        <source>Installing downloaded files</source>
        <translation>Installerer nedlastede filer</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="198"/>
        <source>No downloaded *.debs files found.</source>
        <translation>Ingen lagrede *.debs filer funnet.</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="211"/>
        <source>&lt;b&gt;Installing...&lt;/b&gt;&lt;p&gt;</source>
        <translation>&lt;b&gt;Installerer...&lt;/b&gt;&lt;p&gt;</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="215"/>
        <source>Error installing %1</source>
        <translation>Feil ved installasjon av %1</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="219"/>
        <source>Fix missing dependencies...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="221"/>
        <source>Error running &apos;apt-get -fm install&apos; command</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="233"/>
        <source>&lt;b&gt;Installation process has finished&lt;/b&gt;</source>
        <translation>&lt;b&gt;Installasjonsprosessen er fullført&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="236"/>
        <source>Finished</source>
        <translation>Fullført</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="237"/>
        <source>Codecs files have been downloaded and installed successfully.</source>
        <translation>Codecfiler har blitt lagret og installert uten feil.</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="241"/>
        <source>Process finished. Errors have occurred during the installation.</source>
        <translation>Installasjonsprosess fullført. Feil har forekommet under installasjonen.</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="256"/>
        <source>About MX Codecs</source>
        <translation>Om MX Codecer</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="257"/>
        <source>MX Codecs</source>
        <translation>MX Codecer</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="257"/>
        <source>Version: </source>
        <translation>Versjon:</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="259"/>
        <source>Simple codecs downloader for MX Linux</source>
        <translation>Enkel codec-nedlaster for MX Linux</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="260"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="261"/>
        <source>License</source>
        <translation>Lisens</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="262"/>
        <source>Changelog</source>
        <translation>Changelog</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="278"/>
        <source>&amp;Close</source>
        <translation>&amp;Lukk</translation>
    </message>
</context>
</TS>
